# Generated by Django 4.2.23 on 2025-08-14 23:58

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fittings', '0016_remove_dogmaattribute_type_remove_dogmaeffect_type_and_more'),
        ('auth', '0012_alter_user_first_name_max_length'),
        ('markettracker', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='DiscordMessage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('item_alert_header', models.CharField(default='⚠️ MarketTracker Items', help_text='Header used for items alerts', max_length=200)),
                ('contract_alert_header', models.CharField(default='📦 MarketTracker Contracts', help_text='Header used for contract alerts', max_length=200)),
                ('item_ping_choice', models.CharField(blank=True, help_text='Special ping target: none, here, everyone', max_length=16, null=True)),
                ('contract_ping_choice', models.CharField(blank=True, help_text='Special ping target: none, here, everyone', max_length=16, null=True)),
                ('contract_ping_group', models.ForeignKey(blank=True, help_text='Discord role (from AA group) to ping for contracts', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='markettracker_contract_pings', to='auth.group')),
                ('item_ping_group', models.ForeignKey(blank=True, help_text='Discord role (from AA group) to ping for items', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='markettracker_item_pings', to='auth.group')),
            ],
            options={
                'default_permissions': (),
            },
        ),
        migrations.RemoveField(
            model_name='markettrackingconfig',
            name='contract_discord_alert_header',
        ),
        migrations.RemoveField(
            model_name='markettrackingconfig',
            name='discord_alert_header',
        ),
        migrations.RemoveField(
            model_name='markettrackingconfig',
            name='discord_ping_group',
        ),
        migrations.RemoveField(
            model_name='markettrackingconfig',
            name='discord_ping_group_text',
        ),
        migrations.RemoveField(
            model_name='markettrackingconfig',
            name='discord_webhooks',
        ),
        migrations.RemoveField(
            model_name='trackedcontract',
            name='last_status',
        ),
        migrations.AlterField(
            model_name='discordwebhook',
            name='name',
            field=models.CharField(default='Webhook', max_length=100),
        ),
        migrations.AlterField(
            model_name='discordwebhook',
            name='url',
            field=models.URLField(unique=True),
        ),
        migrations.AlterField(
            model_name='markettrackingconfig',
            name='red_threshold',
            field=models.PositiveIntegerField(default=25, verbose_name='Red status threshold (%)'),
        ),
        migrations.AlterField(
            model_name='markettrackingconfig',
            name='yellow_threshold',
            field=models.PositiveIntegerField(default=50, verbose_name='Yellow status threshold (%)'),
        ),
        migrations.AlterField(
            model_name='trackedcontract',
            name='desired_quantity',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='trackedcontract',
            name='fitting',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='fittings.fitting'),
        ),
        migrations.AlterField(
            model_name='trackedcontract',
            name='title_filter',
            field=models.CharField(blank=True, max_length=120),
        ),
        migrations.DeleteModel(
            name='MarketOrderSnapshot',
        ),
    ]
