# Generated by Django 4.2.23 on 2025-12-19 15:36

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('markettracker', '0007_contractsnapshot_date_completed'),
    ]

    operations = [
        migrations.CreateModel(
            name='MTTaskLog',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(db_index=True, default=django.utils.timezone.now)),
                ('level', models.CharField(db_index=True, default='INFO', max_length=10)),
                ('source', models.CharField(db_index=True, default='contracts', max_length=64)),
                ('event', models.CharField(db_index=True, default='run', max_length=64)),
                ('message', models.TextField(blank=True, default='')),
                ('data', models.JSONField(blank=True, null=True)),
            ],
            options={
                'ordering': ['-created'],
            },
        ),
    ]
