# Generated by Django 4.2.23 on 2025-12-02 16:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('markettracker', '0005_seed_default_tracking_config'),
    ]

    operations = [
        migrations.AddField(
            model_name='discordmessage',
            name='item_restocked_alert_header',
            field=models.CharField(default='👍 Items back in stock', help_text='Header used for items restock alerts', max_length=200),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='item_restocked_ping_choice',
            field=models.CharField(blank=True, help_text='Special ping target: none, here, everyone', max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='item_restocked_ping_group',
            field=models.ForeignKey(blank=True, help_text='Discord role (from AA group) to ping for items restocked', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='markettracker_item_restocked_pings', to='auth.group'),
        ),
    ]
