# Generated by Django 4.2.23 on 2025-08-15 10:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('markettracker', '0003_marketordersnapshot'),
    ]

    operations = [
        migrations.AddField(
            model_name='trackedcontract',
            name='last_status',
            field=models.CharField(default='OK', max_length=10),
        ),
    ]
